@@ -514,6 +514,10 @@ class Scanner(object):
             self.conf.branch_name_re,
             flags=re.VERBOSE | re.UNICODE,
         )
+        self._ignore_uids = set(
+            _get_unique_id(fn)
+            for fn in self.conf.ignore_notes
+        )
 
     def _get_ref(self, name):
         if name:
@@ -528,7 +532,17 @@ class Scanner(object):
                 # name exists on the 'origin' remote.
                 'refs/remotes/origin/' + name,
             ]
+            # If the reference points explicitly to the origin remote,
+            # but that remote isn't present (as it won't be when zuul
+            # configures the repo in CI), then we want the shortened
+            # form of the reference. We put this option last in the
+            # list because we want the more explicit name to be used
+            # when someone is running reno locally with a more
+            # standard git configuration.
+            if name.startswith('origin/'):
+                candidates.append('refs/heads/' + name.partition('/')[-1])
             for ref in candidates:
+                LOG.debug('looking for ref {!r} as {!r}'.format(name, ref))
                 key = ref.encode('utf-8')
                 if key in self._repo.refs:
                     sha = self._repo.refs[key]
@@ -538,6 +552,8 @@ class Scanner(object):
                         # signed tags point to the signature and we
                         # need to dereference it to get to the commit.
                         sha = o.object[1]
+                    LOG.info('found ref {!r} as {!r} at {}'.format(
+                        name, ref, sha))
                     return sha
             # If we end up here we didn't find any of the candidates.
             raise ValueError('Unknown reference {!r}'.format(name))
@@ -1069,6 +1085,11 @@ class Scanner(object):
             for change in aggregator.aggregate_changes(entry, changes):
                 uniqueid = change[0]
 
+                if uniqueid in self._ignore_uids:
+                    LOG.info('ignoring %s based on configuration setting',
+                             uniqueid)
+                    continue
+
                 c_type = change[1]
 
                 if c_type == diff_tree.CHANGE_ADD:
